@@ -55,13 +55,13 @@ QString *Deinflection::getWordType()
 EntryList *Deinflection::search(const DictQuery &query, const QVector<QString> &preliminaryResults)
 {
     if (conjugationList == nullptr) {
-        return NULL;
+        return nullptr;
     }
 
     m_deinflectionLabel = QString();
     m_wordType = QString();
 
-    EntryList *entries = new EntryList();
+    auto entries = new EntryList();
 
     QStringList edictTypesList;
     edictTypesList.append(EdictFormatting::Adjectives);
@@ -83,10 +83,10 @@ EntryList *Deinflection::search(const DictQuery &query, const QVector<QString> &
             delete entry;
     }
 
-    EntryList *results = new EntryList();
+    auto results = new EntryList();
     EntryList::EntryIterator it(*entries);
     while (it.hasNext()) {
-        EntryEdict *entry = static_cast<EntryEdict *>(it.next());
+        auto entry = static_cast<EntryEdict *>(it.next());
 
         QString text = query.getWord();
         if (text.isEmpty()) {
@@ -96,7 +96,7 @@ EntryList *Deinflection::search(const DictQuery &query, const QVector<QString> &
                 entries->deleteAll();
                 delete entries;
                 delete results;
-                return NULL;
+                return nullptr;
             }
         }
 
