@@ -37,7 +37,7 @@ QString *DictFileEdict::wordType = nullptr;
  */
 DictFileEdict::DictFileEdict()
     : DictFile(EDICT)
-    , m_deinflection(0)
+    , m_deinflection(nullptr)
     , m_hasDeinflection(false)
 {
     m_dictionaryType = EDICT;
@@ -85,7 +85,7 @@ EntryList *DictFileEdict::doSearch(const DictQuery &query)
                 // The nastiest situation... we have to assemble a search string
                 // from the first property
                 QList<QString> keys = query.listPropertyKeys();
-                if (keys.size() == 0) // Shouldn't happen... but maybe in the future
+                if (keys.empty()) // Shouldn't happen... but maybe in the future
                 {
                     return new EntryList();
                 }
@@ -102,16 +102,16 @@ EntryList *DictFileEdict::doSearch(const DictQuery &query)
 
     QVector<QString> preliminaryResults = m_edictFile.findMatches(firstChoice);
 
-    if (preliminaryResults.size() == 0) // If there were no matches... return an empty list
+    if (preliminaryResults.empty()) // If there were no matches... return an empty list
     {
         return new EntryList();
     }
 
-    EntryList *results = new EntryList();
+    auto results = new EntryList();
     foreach (const QString &it, preliminaryResults) {
         //     qDebug() << "result: " << it << endl;
         Entry *result = makeEntry(it);
-        EntryEdict *resultEdict = static_cast<EntryEdict *>(result);
+        auto resultEdict = static_cast<EntryEdict *>(result);
         if (result->matchesQuery(query) && resultEdict->matchesWordType(query)) {
             results->append(result);
         } else {
@@ -141,11 +141,11 @@ EntryList *DictFileEdict::doSearch(const DictQuery &query)
     }
 
     if (results) {
-        EntryList *common = new EntryList();
-        EntryList *uncommon = new EntryList();
+        auto common = new EntryList();
+        auto uncommon = new EntryList();
         EntryList::EntryIterator i(*results);
         while (i.hasNext()) {
-            EntryEdict *entry = static_cast<EntryEdict *>(i.next());
+            auto entry = static_cast<EntryEdict *>(i.next());
             if (entry->isCommon()) {
                 common->append(entry);
             } else {
@@ -160,10 +160,10 @@ EntryList *DictFileEdict::doSearch(const DictQuery &query)
         delete common;
         delete uncommon;
 
-        EntryList *exact = new EntryList();
-        EntryList *beginning = new EntryList();
-        EntryList *ending = new EntryList();
-        EntryList *anywhere = new EntryList();
+        auto exact = new EntryList();
+        auto beginning = new EntryList();
+        auto ending = new EntryList();
+        auto anywhere = new EntryList();
         EntryList::EntryIterator it(*results);
         while (it.hasNext()) {
             Entry *entry = it.next();
@@ -283,7 +283,7 @@ inline Entry *DictFileEdict::makeEntry(const QString &entry)
 
 DictionaryPreferenceDialog *DictFileEdict::preferencesWidget(KConfigSkeleton *config, QWidget *parent)
 {
-    DictFileFieldSelector *dialog = new DictFileFieldSelector(config, getType(), parent);
+    auto dialog = new DictFileFieldSelector(config, getType(), parent);
     dialog->addAvailable(listDictDisplayOptions(QStringList()));
     return dialog;
 }
