@@ -108,7 +108,7 @@ void RadSelect::optionsPreferences()
     }
 
     KConfigDialog *dialog = new KConfigDialog(this, QStringLiteral("settings"), RadSelectConfigSkeleton::self());
-    QWidget *preferences = new QWidget();
+    auto preferences = new QWidget();
     Ui::radselectprefdialog layout;
     layout.setupUi(preferences);
     dialog->addPage(preferences, i18n("Settings"), QStringLiteral("help-contents"));
@@ -134,7 +134,7 @@ void RadSelect::saveProperties(KConfigGroup &config)
 // is in some other way given priority.
 void RadSelect::sendSearch(const QStringList &kanji)
 {
-    if (kanji.size() == 0) {
+    if (kanji.empty()) {
         return;
     }
 
@@ -150,3 +150,5 @@ void RadSelect::sendSearch(const QStringList &kanji)
         }
     }
 }
+
+#include "moc_radselect.cpp"
